@@ -35,7 +35,8 @@ if(!exists("trip_headsign", where = gtfs$trips)) {
   trip_headsigns <- gtfs$stop_times %>% 
     group_by(trip_id) %>% 
     summarise(stop_id = stop_id[which.max(stop_sequence)]) %>% 
-    left_join(gtfs$stops, by="stop_id") %>% select(trip_id, trip_headsign.computed = stop_name)
+    left_join(gtfs$stops, by="stop_id") %>%
+    select(trip_id, trip_headsign.computed = stop_name)
 
   # assign the headsign to the gtfs object 
   gtfs$trips <- left_join(gtfs$trips, trip_headsigns, by = "trip_id")
@@ -96,12 +97,13 @@ departures_180823 %>%
 
 ## ----fig.width=8, fig.height=6------------------------------------------------
 route_colors <- gtfs$routes %>% select(route_id, route_short_name, route_color)
-route_colors$route_color[which(is.na(route_colors$route_color))] <- "454545"
+route_colors$route_color[which(route_colors$route_color == "")] <- "454545"
 route_colors <- setNames(paste0("#", route_colors$route_color), route_colors$route_short_name)
 
 ggplot(departures_180823) + theme_bw() +
   geom_point(aes(y=trip_headsign, x=departure_time, color = route_short_name), size = 0.2) +
-  scale_x_time(breaks = seq(0, max(as.numeric(departures$departure_time)), 3600), labels = scales::time_format("%H:%M")) +
+  scale_x_time(breaks = seq(0, max(as.numeric(departures$departure_time)), 3600), 
+               labels = scales::time_format("%H:%M")) +
   theme(axis.text.x = element_text(angle = 90, hjust = 1)) +
   theme(legend.position = "bottom") +
   scale_color_manual(values = route_colors) +
